You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cloudstack.apache.org by al...@apache.org on 2013/06/20 00:12:34 UTC

git commit: updated refs/heads/master to 0a4e651

Updated Branches:
  refs/heads/master 5cd6d6944 -> 0a4e65126


CLOUDSTACK-3079: Use global var "ping.timeout" as a multiplier to ping.interval before announcing an agent has timed out. The multiplier used to be hardcoded to 3


Project: http://git-wip-us.apache.org/repos/asf/cloudstack/repo
Commit: http://git-wip-us.apache.org/repos/asf/cloudstack/commit/0a4e6512
Tree: http://git-wip-us.apache.org/repos/asf/cloudstack/tree/0a4e6512
Diff: http://git-wip-us.apache.org/repos/asf/cloudstack/diff/0a4e6512

Branch: refs/heads/master
Commit: 0a4e65126fd297a7e04ee746b51ebd0cd8137998
Parents: 5cd6d69
Author: Alena Prokharchyk <al...@citrix.com>
Authored: Wed Jun 19 14:38:25 2013 -0700
Committer: Alena Prokharchyk <al...@citrix.com>
Committed: Wed Jun 19 15:11:53 2013 -0700

----------------------------------------------------------------------
 .../src/com/cloud/agent/manager/ClusteredAgentManagerImpl.java   | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cloudstack/blob/0a4e6512/server/src/com/cloud/agent/manager/ClusteredAgentManagerImpl.java
----------------------------------------------------------------------
diff --git a/server/src/com/cloud/agent/manager/ClusteredAgentManagerImpl.java b/server/src/com/cloud/agent/manager/ClusteredAgentManagerImpl.java
index 3ce60b7..19f0102 100755
--- a/server/src/com/cloud/agent/manager/ClusteredAgentManagerImpl.java
+++ b/server/src/com/cloud/agent/manager/ClusteredAgentManagerImpl.java
@@ -173,8 +173,8 @@ public class ClusteredAgentManagerImpl extends AgentManagerImpl implements Clust
             s_logger.trace("Begin scanning directly connected hosts");
         }
 
-        // for agents that are self-managed, threshold to be considered as disconnected is 3 ping intervals
-        long cutSeconds = (System.currentTimeMillis() >> 10) - (_pingInterval * 3);
+        // for agents that are self-managed, threshold to be considered as disconnected after pingtimeout
+        long cutSeconds = (System.currentTimeMillis() >> 10) - (_pingTimeout);
         List<HostVO> hosts = _hostDao.findAndUpdateDirectAgentToLoad(cutSeconds, _loadSize, _nodeId);
         List<HostVO> appliances = _hostDao.findAndUpdateApplianceToLoad(cutSeconds, _nodeId);
         hosts.addAll(appliances);